Upcoming Changes
@@@@@@@@@@@@@@@@@@@@@@@@@@@@

This page highlights changes expected for 0.5.0, which will likely be
released in late 2015. For a full list of issues targeted for that
version, see `milestone 0.5.0
<https://bitbucket.org/biocommons/hgvs/issues?milestone=0.5.0>`_.

Special Attention
$$$$$$$$$$$$$$$$$

* connection parameters
* API changes likely 
  

Anticipated Features
$$$$$$$$$$$$$$$$$$$$

* SeqDB sequence fetching
* REST Interface
* Complex variants
